@@ -29,13 +29,13 @@ sub iterate {
     for (my $i=0; $i< $length; $i++){
         my $payload_item = $command->{payload}[$i];
         if(blessed($payload_item) and $payload_item->isa('Javonet::Sdk::Core::PerlCommand')
-            and !($payload_item->{command_type} eq Javonet::Sdk::Core::PerlCommandType::get_command_type('Response'))) {
+            and !($payload_item->{command_type} eq Javonet::Sdk::Core::PerlCommandType::get_command_type('Value'))) {
             $command->{payload}[$i] = Javonet::Core::Handler::HandlerDictionary::get_handler(
                 $command->{payload}[$i]->{command_type})->handle_command($command->{payload}[$i]
             );
         }
         if(blessed($payload_item) and $payload_item->isa('Javonet::Sdk::Core::PerlCommand')
-            and $payload_item->{command_type} eq Javonet::Sdk::Core::PerlCommandType::get_command_type('Response')) {
+            and $payload_item->{command_type} eq Javonet::Sdk::Core::PerlCommandType::get_command_type('Value')) {
             $command->{payload}[$i] = $payload_item->{payload}[0];
         }
     }
